Displaying 20 results from an estimated 99 matches for "521,7".
Did you mean:
21,7
2015 Feb 19
2
[LLVMdev] [PATCH] Minor typos corrected in docs
...oesn't use many registers. The cold path might need to call out to
another function and therefore only needs to preserve the caller-saved
registers, which haven't already been saved by the caller. The
`PreserveMost` calling convention is very similar to the `cold` calling
@@ -521,7 +521,7 @@
Global variables define regions of memory allocated at compilation time
instead of run-time.
-Global variables definitions must be initialized.
+Global variable definitions must be initialized.
Global variables in other translation units can also be declared, in which
case they don'...
2012 Sep 03
3
[PATCH] virtio-blk: Fix kconfig option
...igned-off-by: Kent Overstreet <koverstreet at google.com>
---
drivers/block/Kconfig | 3 ++-
1 file changed, 2 insertions(+), 1 deletion(-)
diff --git a/drivers/block/Kconfig b/drivers/block/Kconfig
index a796407..d4e1d12 100644
--- a/drivers/block/Kconfig
+++ b/drivers/block/Kconfig
@@ -521,7 +521,8 @@ config XEN_BLKDEV_BACKEND
config VIRTIO_BLK
tristate "Virtio block driver (EXPERIMENTAL)"
- depends on EXPERIMENTAL && VIRTIO
+ select VIRTIO
+ depends on EXPERIMENTAL
---help---
This is the virtual block driver for virtio. It can be used with
lg...
2012 Sep 03
3
[PATCH] virtio-blk: Fix kconfig option
...igned-off-by: Kent Overstreet <koverstreet at google.com>
---
drivers/block/Kconfig | 3 ++-
1 file changed, 2 insertions(+), 1 deletion(-)
diff --git a/drivers/block/Kconfig b/drivers/block/Kconfig
index a796407..d4e1d12 100644
--- a/drivers/block/Kconfig
+++ b/drivers/block/Kconfig
@@ -521,7 +521,8 @@ config XEN_BLKDEV_BACKEND
config VIRTIO_BLK
tristate "Virtio block driver (EXPERIMENTAL)"
- depends on EXPERIMENTAL && VIRTIO
+ select VIRTIO
+ depends on EXPERIMENTAL
---help---
This is the virtual block driver for virtio. It can be used with
lg...
2007 Apr 19
0
[PATCH] Make focusDefaultWindow () take a CompScreen as argument
...eFromDisplay (CompDisplay *d);
void
-focusDefaultWindow (CompDisplay *d);
+focusDefaultWindow (CompScreen *s);
void
forEachWindowOnDisplay (CompDisplay *display,
diff --git a/plugins/rotate.c b/plugins/rotate.c
index bf6bb95..640c8f4 100644
--- a/plugins/rotate.c
+++ b/plugins/rotate.c
@@ -521,7 +521,7 @@ rotatePreparePaintScreen (CompScreen *s,
/* only focus default window if switcher isn't active */
if (i == s->maxGrab)
- focusDefaultWindow (s->display);
+ focusDefaultWindow (s);
}
rs->moveWindow = 0;
--
1.8.4
2014 Sep 25
2
[PATCH] virtio_balloon: Convert "vballon" kthread into a workqueue
...@@ static void virtballoon_remove(struct virtio_device *vdev)
{
struct virtio_balloon *vb = vdev->priv;
- kthread_stop(vb->thread);
+ destroy_workqueue(vb->wq);
remove_common(vb);
balloon_mapping_free(vb->vb_dev_info->mapping);
balloon_devinfo_free(vb->vb_dev_info);
@@ -521,7 +521,7 @@ static int virtballoon_freeze(struct virtio_device *vdev)
struct virtio_balloon *vb = vdev->priv;
/*
- * The kthread is already frozen by the PM core before this
+ * The workqueue is already frozen by the PM core before this
* function is called.
*/
--
1.8.4
2016 Dec 07
0
[PATCH v2 1/4] vsock: track pkt owner vsock
...loc(len, GFP_KERNEL);
@@ -180,6 +181,7 @@ static int virtio_transport_send_credit_update(struct vsock_sock *vsk,
struct virtio_vsock_pkt_info info = {
.op = VIRTIO_VSOCK_OP_CREDIT_UPDATE,
.type = type,
+ .vsk = vsk,
};
return virtio_transport_send_pkt_info(vsk, &info);
@@ -519,6 +521,7 @@ int virtio_transport_connect(struct vsock_sock *vsk)
struct virtio_vsock_pkt_info info = {
.op = VIRTIO_VSOCK_OP_REQUEST,
.type = VIRTIO_VSOCK_TYPE_STREAM,
+ .vsk = vsk,
};
return virtio_transport_send_pkt_info(vsk, &info);
@@ -534,6 +537,7 @@ int virtio_transport_shutdown(s...
2016 Dec 08
0
[PATCH v3 1/4] vsock: track pkt owner vsock
...loc(len, GFP_KERNEL);
@@ -180,6 +181,7 @@ static int virtio_transport_send_credit_update(struct vsock_sock *vsk,
struct virtio_vsock_pkt_info info = {
.op = VIRTIO_VSOCK_OP_CREDIT_UPDATE,
.type = type,
+ .vsk = vsk,
};
return virtio_transport_send_pkt_info(vsk, &info);
@@ -519,6 +521,7 @@ int virtio_transport_connect(struct vsock_sock *vsk)
struct virtio_vsock_pkt_info info = {
.op = VIRTIO_VSOCK_OP_REQUEST,
.type = VIRTIO_VSOCK_TYPE_STREAM,
+ .vsk = vsk,
};
return virtio_transport_send_pkt_info(vsk, &info);
@@ -534,6 +537,7 @@ int virtio_transport_shutdown(s...
2016 Dec 12
0
[PATCH v4 1/4] vsock: track pkt owner vsock
...loc(len, GFP_KERNEL);
@@ -180,6 +181,7 @@ static int virtio_transport_send_credit_update(struct vsock_sock *vsk,
struct virtio_vsock_pkt_info info = {
.op = VIRTIO_VSOCK_OP_CREDIT_UPDATE,
.type = type,
+ .vsk = vsk,
};
return virtio_transport_send_pkt_info(vsk, &info);
@@ -519,6 +521,7 @@ int virtio_transport_connect(struct vsock_sock *vsk)
struct virtio_vsock_pkt_info info = {
.op = VIRTIO_VSOCK_OP_REQUEST,
.type = VIRTIO_VSOCK_TYPE_STREAM,
+ .vsk = vsk,
};
return virtio_transport_send_pkt_info(vsk, &info);
@@ -534,6 +537,7 @@ int virtio_transport_shutdown(s...
2019 Sep 16
0
[PATCH 5/8] v2v: add output#disk_copied hook
...o do work right after a disk
was successfully copied.
---
v2v/types.ml | 1 +
v2v/types.mli | 4 ++++
v2v/v2v.ml | 9 ++++++++-
3 files changed, 13 insertions(+), 1 deletion(-)
diff --git a/v2v/types.ml b/v2v/types.ml
index 77f879200..714b30014 100644
--- a/v2v/types.ml
+++ b/v2v/types.ml
@@ -521,6 +521,7 @@ class virtual output = object
method override_output_format (_ : overlay) = (None : string option)
method virtual prepare_targets : source -> (string * overlay) list -> target_buses -> guestcaps -> inspect -> target_firmware -> target_file list
method disk_cre...
2009 Mar 22
2
[PATCH 1/3] pci: remove (void)cfgtype;
...inux-3.74-pre11-2-g4fc8259/com32/lib/pci/scan.c
@@ -441,7 +441,6 @@ struct pci_domain *pci_scan(void)
int cfgtype;
cfgtype = pci_set_config_type(PCI_CFG_AUTO);
- (void)cfgtype;
dprintf("PCI configuration type %d\n", cfgtype);
dprintf("Scanning PCI Buses\n");
@@ -521,7 +520,6 @@ void gather_additional_pci_config(struct
pciaddr_t a;
int cfgtype;
cfgtype = pci_set_config_type(PCI_CFG_AUTO);
- (void)cfgtype;
for (nbus = 0; nbus < MAX_PCI_BUSES; nbus++) {
bus = NULL;
2011 Mar 31
4
[PATCH] Btrfs: fix free space cache when there are pinned extents and clusters
...ge;
struct extent_state *cached_state = NULL;
+ struct btrfs_free_cluster *cluster = NULL;
+ struct extent_io_tree *unpin = NULL;
struct list_head bitmap_list;
struct btrfs_key key;
+ u64 start, end, len;
u64 bytes = 0;
u32 *crc, *checksums;
pgoff_t index = 0, last_index = 0;
@@ -505,6 +521,7 @@ int btrfs_write_out_cache(struct btrfs_root *root,
int entries = 0;
int bitmaps = 0;
int ret = 0;
+ bool next_page = false;
root = root->fs_info->tree_root;
@@ -551,6 +568,18 @@ int btrfs_write_out_cache(struct btrfs_root *root,
*/
first_page_offset = (sizeof(u32) * num_...
2019 Jan 01
2
[PATCH nbdkit] server: Use bool for types which are really booleans.
...rypto.c b/server/crypto.c
index 5b01684..4638a69 100644
--- a/server/crypto.c
+++ b/server/crypto.c
@@ -230,7 +230,7 @@ start_psk (void)
* and loading the server certificate.
*/
void
-crypto_init (int tls_set_on_cli)
+crypto_init (bool tls_set_on_cli)
{
int err, r;
const char *what;
@@ -521,7 +521,7 @@ crypto_negotiate_tls (struct connection *conn, int sockin, int sockout)
*/
void
-crypto_init (int tls_set_on_cli)
+crypto_init (bool tls_set_on_cli)
{
if (tls > 0) {
fprintf (stderr,
diff --git a/src/display.c b/src/d...
2015 May 14
1
[PATCH] When calling getline first time, initialize length to zero.
...main.c
@@ -306,7 +306,7 @@ partition_parent (dev_t part_dev)
{
CLEANUP_FCLOSE FILE *fp = NULL;
CLEANUP_FREE char *path = NULL, *content = NULL;
- size_t len;
+ size_t len = 0;
unsigned parent_major, parent_minor;
if (asprintf (&path, "/sys/dev/block/%d:%d/../dev",
@@ -521,7 +521,7 @@ read_cmdline (void)
{
CLEANUP_FCLOSE FILE *fp = NULL;
char *ret = NULL;
- size_t len;
+ size_t len = 0;
fp = fopen ("/proc/cmdline", "re");
if (fp == NULL) {
--
2.3.1
2007 Jul 14
0
libswfdec/swfdec_as_interpret.c libswfdec/swfdec_as_string.c libswfdec/swfdec_bits.c
..._convert (msg, -1, "LATIN1", "UTF8", NULL, NULL, NULL);
+ in = s = g_convert (msg, -1, "LATIN1", "UTF-8", NULL, NULL, NULL);
if (s == NULL) {
SWFDEC_FIXME ("%s can not be converted to utf8 - is this Flash 5 or what?", msg);
return;
@@ -521,7 +521,7 @@ swfdec_as_string_unescape_5 (SwfdecAsCon
}
cur = 0;
g_byte_array_append (array, (guchar *) &cur, 1);
- out = g_convert ((char *) array->data, -1, "UTF8", "LATIN1", NULL, NULL, NULL);
+ out = g_convert ((char *) array->data, -1, "UTF-8",...
2004 Nov 25
5
newnotsyn responsible for sporadic delays?
Has anyone encountered a situation where packets dropped by the
newnotsyn chain can result in sporadic browsing problems, slowness, and
even timeouts?
I noticed that of the 3300 hits for newnotsyn in our current log (6 hours
worth), over 2700 of them were to/from our proxy servers. And browsing
through them, most *appear* to be otherwise valid packets from remote
web servers that would have
2014 Apr 30
1
[PATCH 1/2] nouveau: remove cb_dirty, it's never used
....h | 1 -
2 files changed, 1 insertion(+), 4 deletions(-)
diff --git a/src/gallium/drivers/nouveau/nouveau_buffer.c b/src/gallium/drivers/nouveau/nouveau_buffer.c
index e308ff4..904e2cc 100644
--- a/src/gallium/drivers/nouveau/nouveau_buffer.c
+++ b/src/gallium/drivers/nouveau/nouveau_buffer.c
@@ -521,7 +521,7 @@ nouveau_buffer_transfer_flush_region(struct pipe_context *pipe,
* was returned was not the real resource's data, this needs to transfer the
* data back to the resource.
*
- * Also marks vbo/cb dirty if the buffer's binding
+ * Also marks vbo dirty based on the buffer's...
2014 Sep 25
2
[PATCH] virtio_balloon: Convert "vballon" kthread into a workqueue
...@@ static void virtballoon_remove(struct virtio_device *vdev)
{
struct virtio_balloon *vb = vdev->priv;
- kthread_stop(vb->thread);
+ destroy_workqueue(vb->wq);
remove_common(vb);
balloon_mapping_free(vb->vb_dev_info->mapping);
balloon_devinfo_free(vb->vb_dev_info);
@@ -521,7 +521,7 @@ static int virtballoon_freeze(struct virtio_device *vdev)
struct virtio_balloon *vb = vdev->priv;
/*
* The kthread is already frozen by the PM core before this
* function is called.
*/
@@ -521,7 +521,7 @@ static int virtballoon_freeze(struct virtio_device *vdev)
struct virtio_balloon *vb = vdev->priv;
/*
- * The kthread is already frozen by the PM core before this
+ * The workqueue is already frozen by the PM core before this
* function is called.
*/
diff --git a/server/main.c b/server/main.c
index e8a15f7..5e538bf 100644
--- a/server/m...
2013 Sep 05
16
[PATCH] minios: Fix xenbus_rm() calls in frontend drivers
...rintf(nodename, sizeof(nodename), "%s/event-channel", dev->nodename);
+ xenbus_rm(XBT_NIL, nodename);
+ snprintf(nodename, sizeof(nodename), "%s/request-abs-pointer", dev->nodename);
+ xenbus_rm(XBT_NIL, nodename);
if (!err)
free_kbdfront(dev);
@@ -521,7 +520,7 @@ done:
{
XenbusState state;
char path[strlen(dev->backend) + 1 + 14 + 1];
- char frontpath[strlen(nodename) + 1 + 6 + 1];
+ char frontpath[strlen(nodename) + 1 + 5 + 1];
snprintf(path, sizeof(path), "%s/state", dev->backend)...
2007 Apr 18
1
[PATCH 2/9] Sched clock paravirt op fix.patch
...t.c Thu Feb 15 23:52:41 2007 -0800
+++ b/arch/i386/kernel/paravirt.c Fri Feb 16 00:04:39 2007 -0800
@@ -32,6 +32,7 @@
#include <asm/fixmap.h>
#include <asm/apic.h>
#include <asm/tlbflush.h>
+#include <asm/timer.h>
/* nop stub */
static void native_nop(void)
@@ -520,6 +521,7 @@ struct paravirt_ops paravirt_ops = {
.write_msr = native_write_msr,
.read_tsc = native_read_tsc,
.read_pmc = native_read_pmc,
+ .get_scheduled_cycles = native_read_tsc,
.load_tr_desc = native_load_tr_desc,
.set_ldt = native_set_ldt,
.load_gdt = native_load_gdt,
diff -r d58e6ddfdfa9...
2007 Apr 18
1
[PATCH 2/9] Sched clock paravirt op fix.patch
...t.c Thu Feb 15 23:52:41 2007 -0800
+++ b/arch/i386/kernel/paravirt.c Fri Feb 16 00:04:39 2007 -0800
@@ -32,6 +32,7 @@
#include <asm/fixmap.h>
#include <asm/apic.h>
#include <asm/tlbflush.h>
+#include <asm/timer.h>
/* nop stub */
static void native_nop(void)
@@ -520,6 +521,7 @@ struct paravirt_ops paravirt_ops = {
.write_msr = native_write_msr,
.read_tsc = native_read_tsc,
.read_pmc = native_read_pmc,
+ .get_scheduled_cycles = native_read_tsc,
.load_tr_desc = native_load_tr_desc,
.set_ldt = native_set_ldt,
.load_gdt = native_load_gdt,
diff -r d58e6ddfdfa9...